cmd

package
v0.0.0-...-eb73805 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunCut

func RunCut(args []string) error

RunCut marks the given files/directories for cutting.

func RunInstall

func RunInstall(args []string) error

RunInstall sets up macOS Quick Actions and prints shortcut instructions.

func RunPaste

func RunPaste(args []string) error

RunPaste moves all cut files into the target directory. If no target is given, the current working directory is used.

Types

This section is empty.

Jump to